@@ -12,7 +12,7 @@
 ##################################################################
 
 Version = '1.11'
-Build = '2'
+Build = '3'
 
 import sys
 import os
@@ -611,7 +611,7 @@ class clevenDecryptCaptured(QtGui.QMainWindow): # Complete
              name = self.capfile.strip().partition('-')
              cap = name[0]
           else:
-             cap = self.capfile.strip().replace('.cap','')
+             cap = self.capfile.strip().replace('.cap','').replace('.ivs','')
           print "delete cap: ", cap
 
           os.system('sudo %s/%s deleteCaptured %s %s %s' % (pathMain, helperScript, pathTemp, encryption, cap))
